@@ -2,7 +2,7 @@
 #'  their kingdom and rank ID values.
 #'
 #' @export
-#' @template common
+#' @inheritParams accepted_names
 #' @return a data.frame, with columns:
 #' \itemize{
 #'  \item kingdomname
@@ -16,7 +16,7 @@ rank_names <- function(wt = "json", raw = FALSE, ...) {
   out <- itis_GET("getRankNames", list(), wt, ...)
   if (raw || wt == "xml") return(out)
   x <- parse_raw(out)$rankNames
-  tibble::as_data_frame(pick_cols(
+  tibble::as_tibble(pick_cols(
     x,
     c("kingdomName", "rankId", "rankName")
   ))
